@@ -159,26 +159,18 @@ html_view_set_adjustments (HtmlView *view)
 	GtkAdjustment *vertical, *horizontal;
 
 	if (view->root) {
-		gint focus_width;
-		gint focus_pad;
-
-		gtk_widget_style_get (GTK_WIDGET (view),
-				      "focus-line-width", &focus_width,
-				      "focus-padding", &focus_pad,
-				      NULL);
-
 		layout = GTK_LAYOUT (view);
 		vertical = layout->vadjustment;
 		horizontal = layout->hadjustment;
 		
 		vertical->lower = 0;
-		vertical->upper = view->root->height + 2 * (focus_width + 2 * focus_pad);
+		vertical->upper = view->root->height; 
 		vertical->page_size = (gfloat)GTK_WIDGET (view)->allocation.height;
 		vertical->step_increment = GTK_WIDGET (view)->allocation.height / 10.0;
 		vertical->page_increment = GTK_WIDGET (view)->allocation.height * 0.9;
 
 		horizontal->lower = 0.0;
-		horizontal->upper = view->root->width + 2 * (focus_width + 2 * focus_pad);
+		horizontal->upper = view->root->width;
 		horizontal->page_size = GTK_WIDGET (view)->allocation.width;
 		horizontal->step_increment = GTK_WIDGET (view)->allocation.width / 10.0;
 		horizontal->page_increment = GTK_WIDGET (view)->allocation.width * 0.9;
@@ -196,19 +188,12 @@ html_view_relayout (HtmlView *view)
 	/* Tell the root layout box to relayout itself */
 	if (view->painter && view->root) {
 		HtmlRelayout *relayout;
-		gint focus_width;
-		gint focus_pad;
 
-		gtk_widget_style_get (GTK_WIDGET (view),
-				      "focus-line-width", &focus_width,
-				      "focus-padding", &focus_pad,
-				      NULL);
-
-		view->root->x = focus_width + 2 * focus_pad;
-		view->root->y = focus_width + 2 * focus_pad;
+		view->root->x = 0;
+		view->root->y = 0;
 		
-		HTML_BOX_ROOT (view->root)->min_width = GTK_WIDGET (view)->allocation.width - 2 * (focus_width + 2 *focus_pad);
-		HTML_BOX_ROOT (view->root)->min_height = GTK_WIDGET (view)->allocation.height - 2 * (focus_width + 2 *focus_pad);
+		HTML_BOX_ROOT (view->root)->min_width = GTK_WIDGET (view)->allocation.width;
+		HTML_BOX_ROOT (view->root)->min_height = GTK_WIDGET (view)->allocation.height;
 		
 		relayout = html_relayout_new ();
 		relayout->type = HTML_RELAYOUT_INCREMENTAL;
@@ -649,25 +634,6 @@ html_view_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	html_view_relayout (view);
 }
 
-static void
-html_view_size_request (GtkWidget *widget, GtkRequisition *requisition)
-{
-	HtmlView *view = HTML_VIEW (widget);
-	gint focus_width;
-	gint focus_pad;
-
-	if (GTK_WIDGET_CLASS (parent_class)->size_request)
-		( *GTK_WIDGET_CLASS (parent_class)->size_request) (widget, requisition);
-
-	gtk_widget_style_get (widget,
-			      "focus-line-width", &focus_width,
-			      "focus-padding", &focus_pad,
-			      NULL);
-
-	requisition->width += 2 * (focus_width + 2 * focus_pad);
-	requisition->height += 2 * (focus_width + 2 * focus_pad);
-}
-
 static void
 html_view_realize (GtkWidget *widget)
 {
@@ -712,76 +678,18 @@ html_view_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 	return TRUE;
 }
 
-static gboolean
-redraw_idle_callback (GtkWidget *widget)
-{
-	gtk_widget_queue_draw (widget);
-	return FALSE;
-}
-
 static gboolean
 html_view_expose (GtkWidget *widget, GdkEventExpose *event)
 {
 	HtmlView *view;
-	gboolean retval;
-	GdkRectangle area;
 
 	view = HTML_VIEW (widget);
 
 	if (!GTK_WIDGET_DRAWABLE (widget) || (event->window != GTK_LAYOUT (view)->bin_window))
 		return FALSE;
 
-	if (GTK_WIDGET_HAS_FOCUS (widget) &&
-	    !view->document->focus_element) {
-		GtkLayout *layout;
-
-		layout = GTK_LAYOUT (view);
-		area.x = (gint) gtk_adjustment_get_value (layout->hadjustment);
-		area.y = (gint) gtk_adjustment_get_value (layout->vadjustment);
-		area.width = widget->allocation.width;
-		area.height = widget->allocation.height;
-
-		if (event->area.x != area.x ||
-		    event->area.y != area.y ||
-		    event->area.width != area.width ||
-		    event->area.height != area.height) {
-			/*
-			 * We need to invalidate the entire area so that the
-			 * focus area is redrawn
-			 */
-			gtk_idle_add (redraw_idle_callback, widget);
-			return TRUE;
-		}
-	}
 	html_view_paint (view, &event->area);
-	retval = GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
-	if (GTK_WIDGET_HAS_FOCUS (widget) &&
-	    !view->document->focus_element) {
-		gint focus_width;
-		gint focus_pad;
-		gint x;
-		gint y;
-		gint width;
-		gint height;
-
-		gtk_widget_style_get (widget,
-				      "focus-line-width", &focus_width,
-				      "focus-padding", &focus_pad,
-				      NULL);
-		x = area.x + focus_pad;
-		y = area.y + focus_pad;
-
-		width = widget->allocation.width - (focus_width + 2 * focus_pad);
-		height = widget->allocation.height - (focus_width + 2 * focus_pad);
-		gtk_paint_focus (widget->style, GTK_LAYOUT (view)->bin_window,
-				 GTK_WIDGET_STATE (widget),
-				 &event->area, widget, "htmlview",
-				 x,
-				 y,
-				 width,
-				 height);
-	}
-	return retval;
+	return GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
 }
 
 
@@ -1189,7 +1097,6 @@ html_view_class_init (HtmlViewClass *klass)
 	widget_class->focus = html_view_focus;
 	
 	widget_class->size_allocate = html_view_size_allocate;
-	widget_class->size_request = html_view_size_request;
 	widget_class->realize = html_view_realize;
 	widget_class->expose_event = html_view_expose;
 	widget_class->motion_notify_event = html_view_motion_notify;
